#
# spec file for package libktorrent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.3.0
%define qt6_version 6.6.0

%bcond_without released
Name:           libktorrent
Version:        24.08.1
Release:        1.1
Summary:        Torrent Downloading Library
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/ktorrent
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  gmp-devel >= 6.0.0
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libboost_headers-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(libgcrypt) >= 1.4.5

%description
libktorrent is a torrent downloading library.

%package -n libKTorrent6
Summary:        Torrent Downloading Library
Provides:       libktorrent = %{version}
Obsoletes:      libktorrent < %{version}
Provides:       libktorrent-lang = %{version}
Obsoletes:      libktorrent-lang < %{version}

%description -n libKTorrent6
libktorrent is a torrent downloading library.

%package devel
Summary:        Development files for libktorrent
Requires:       libKTorrent6 = %{version}
Requires:       libboost_headers-devel >= 1.66.0
Requires:       cmake(KF6Archive) >= %{kf6_version}
Requires:       cmake(KF6Config) >= %{kf6_version}
Requires:       cmake(KF6KIO) >= %{kf6_version}
Requires:       cmake(Qt6Core) >= %{qt6_version}
Requires:       cmake(Qt6Core5Compat) >= %{qt6_version}
Requires:       cmake(Qt6Network) >= %{qt6_version}
Requires:       gmp-devel >= 6.0.0
Requires:       pkgconfig(libgcrypt) >= 1.4.5

%description devel
This package includes the necessary files for development using libktorrent.

%lang_package -n libKTorrent6

%prep
%autosetup -p1

# The boost minimum version change is only cosmetic. Leap 15 only provides 1.66...
sed -i 's#1.71.0#1.66.0#' CMakeLists.txt

%build
%ifarch ppc64
%define _lto_cflags %{nil}
%endif

%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets -n libKTorrent6

%files -n libKTorrent6
%license LICENSES/*
%{_kf6_libdir}/libKTorrent6.so.*

%files devel
%{_kf6_cmakedir}/KTorrent6/
%{_kf6_includedir}/libktorrent/
%{_kf6_libdir}/libKTorrent6.so

%files -n libKTorrent6-lang -f %{name}.lang

%changelog
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- No code change since 24.05.2
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * upnprouter: Send <NewRemoteHost> in forward and undoForward
  * upnprouter: Fix SOAPAction header in UPnP requests
  * changes to allow renaming in ktorrent
  * Clazy: use multi-arg instead
  * Clazy: don't include entire modules, just the classes we need
  * Clazy: don't call first on temporary container
  * Clazy: don't create temporary QRegularExpression objects
  * Clazy: add missing Q_EMIT keywords
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Add missing find_package call for Qt5Compat
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Thu Mar 23 2023 Martin Liška <mliska@suse.cz>
- Enable LTO for ppc64 as it works fine now.
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Do not use deprecated KIO::Scheduler::setJobPriority.
  * Fix build error by making compiler settings less strict.
  * Port away from deprecated KFilterDev.
  * Port away from QMutex::Recursive.
  * mitigate potential DoS vector by limiting pending piece uploads
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Enable Linux and FreeBSD CI
  * dht/KBucket: don't accumulate duplicate replacement entries
  * Clean up "by" usage and multiline statements in license headers
  * Update .gitignore
  * Remove obsolete COPYING-CMAKE-SCRIPTS file
  * Remove obsolete COPYING file
  * Convert MIT license headers to SPDX
  * Put contact information for qt files in angle brackets
  * Remove mail address without any author
  * Put contact information in angle brackets
  * Put contact of multiple authors on separate lines
  * Put info about file being based on sth. else in separate line
  * Clean up license header leftovers
  * Convert license headers to SPDX
  * Add a new SetClientInfo method that accept QString version.
  * dht: expire announcement tokens after 30 minutes
  * Fix upnp closing connection (kde#404135)
  * Handle URLs without host and port in UPnP
  * Fix "signal not found" warning in UPnP plugin
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Thu Aug 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Disable lto for ppc64 builds.
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * respect file priority when selecting preview chunks
  * Fix clang warning and processedAmount deprecation notice.
  * CMP0115 is too new so removing it for now
  * Fix tests with new ecm way
  * add missing include #include <random>
  * update random_shuffle for equivalent of cpp17
  * Increase Cmake deps , fix boost directory and
    make initial c++17 support
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Changes since 20.12.3:
  * Add pre-commit hook for clang-format
  * Add .gitignore file
  * Add .git-blame-ignore-revs file
  * Run clang-format
  * Add trailing comma to enums
  * Add clang-format target
  * Convert some old-style connects
  * raise peer max metasize (torrent file) size to 100mib
  * Fix PeerID for new versioning
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80.
  * New feature release
- libktorrent is now released using the KDE release service.
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use %%cmake_build instead of %%make_jobs
* Mon Jun  8 2020 wbauer@tmo.at
- Update to version 2.2.0
  * DHT improvements (add bootstrapping from well-known nodes, fix
    replying a non 20-bytes long tokens)
  * Quite a few small bugfixes but everything should be more stable
  * Porting away from some deprecated methods
* Sun Sep  1 2019 wbauer@tmo.at
- Update to version 2.1.1
  * Fix HTTP seeding (kde#382375)
  * Fix a few issues found by clang-tidy
  * Some build fixes that get triggered on certain versions of
    Qt/KF5 frameworks
- Drop fix-build-with-qt5.6.patch, merged upstream
- Drop require-lower-LibGMP.patch, no longer necessary as all
  current distribution versions have gmp 6
- Remove conditionals for no longer supported distribution versions
- Add missing requirements to the devel package
- Update URL, ktorrent.org doesn't exist any more
- Run spec-cleaner
* Sat Sep  2 2017 wbauer@tmo.at
- Update to version 2.1.0
- Update build requirements
- Add fix-build-with-qt5.6.patch to fix build with Qt 5.6 or lower
- Drop Fix-logging-framework-spamming.patch, merged upstream
* Sat Feb 11 2017 jengelh@inai.de
- Fix RPM group, remove redundant %%clean section.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Oct 23 2016 hrvoje.senjan@gmail.com
- Added Fix-logging-framework-spamming.patch (kde#362195)
* Sun Sep  4 2016 astieger@suse.com
- libktorrent 2.0.1:
  * Fix ui lags and hangs when downloading to ntfs partition
* Fri Apr 29 2016 hrvoje.senjan@gmail.com
- Added require-lower-LibGMP.patch: 6.0.0 version was chosen
  randomly, and we know the code compiles with at least 5.1.3
* Sat Apr 16 2016 tittiatcoke@gmail.com
- Update to version 2.0
  * Ported to Qt5/KF5
  * QHttp-based tracker communication was dropped in favour of KIO-based one
  * Optimize queue data structures shown up be callgrind
  * fix issues found by Coverity static analyzer
* Fri Jan 18 2013 nico.kruber@gmail.com
- Update to version 1.3.1
  * Add workaround for broken handling of btrfs subvolumes by
    solid (kde#306825)
  * Fix crash when preallocating diskspace when a file is enabled
    during the download of a torrent (kde#307178)
  * Make sure stats get updated properly during data check
    (kde#308707)
  * Bind peer sockets to preferred interface for outbound
    connections
  * Fix bug causing UDP connections not to get established on
    FreeBSD because FIONREAD returns the size of the data and the
    peer address (Review: 108076)
* Wed Sep  5 2012 mlin@suse.com
- Update to version 1.3.0
  * Do not pass link local IPv6 addresses to ip parameter of tracker
    (kde#305187)
  * Implement BEP 32, IPv6 DHT (kde#295194)
  * Revamp DHT code and follow spec more closely on routing table
  * Revamp SingleFileCache, MultiFileCache and data preallocation
  * Webseeds now follow connection limits (kde#184941)
  * Add new SignalCatcher class to handle UNIX signals (kde#296835)
  * Make TimeEstimator return sortable values (kde#298542)
  * Keep track of partitions files of torrents are on
  * Add methods to check if storage is mounted
  * Make sure all trackers are used of a magnet link
    (kde#302997, kde#303269)
  * Fix warning message about locale being recreated
  * Fix crash in DHT code caused by infinite recursion (kde#300974)
* Wed Jun 20 2012 mlin@suse.com
- Update to version 1.2.1
  * Fix deadlock in webseeding code (295719)
  * Fix individual torrent download limit not working
  * Fix build on FreeBSD
  * Fix crash due to attempting to call pop_front on an empty list (299536)
* Tue Mar  6 2012 mlin@suse.com
- Update to version 1.2.0, also lists changes what changed in rc1
  * Fix large file preallocation when not using quick preallocation in some cases
  * Disable current open file checking, it causes performance issues in some situations
  * Don't use the gcrypt version macro in it's version check
  * Make it possible to check data on chunk ranges instead of the entire torrent
  * Move data file jobs are now done one after the other
  * Implement partial seeding extension
  * Add support for IPv6 traffic class field
  * Make sure a torrent is restarted when it was auto stopped and more files are selected for downloading
  * Emit finished signal when torrent is found completely downloaded in data check
  * Seeders and leechers shown in view is now the maximum of all trackers and not the sum
  * Do not add trackers with unsupported protocols
  * Improve SIGBUS handling, fixes a crash
  * Remove usage of several deprecated KDE3 networking classes
  * Remove obsolete functions of data check during upload
  * Simplify blocklist interface
  * Revamp networking code
  * Remove thread from DHT code
  * Prevent file descriptor exhaustion from happening
  * Do not count non piece data in upload speed calculation
  * Fix IPv6 address parsing bug
  * Improve performance of µTP code
  * Fix crash in DHT packet receive code
  * Fill ip parameter of tracker announce with current IPv6 address if not filled in by user in settings
  * Fix crash in PeerManager
  * Fix crash at exit when datachecker job is running
  * Fix crash due to bug in smaller then operator of net::Address
  * Fix crash due to race condition in logging initialization
* Thu Nov 24 2011 asterios.dramis@gmail.com
- Update to 1.1.3:
  * Fix bug causing UPnP not to work properly if there is a question mark in
    the controlurl
  * Fix crash in webseed code (kde#281605)
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Renamed License: to GPL-2.0+ (SPDX style).
* Wed Aug 17 2011 javier@opensuse.org
- Update to 1.1.2:
  * Fix bug causing time left calculation to return something when
    a torrent is paused (bko#272182)
  * Improve performance of UTP delay window algorithm
  * Fix files not getting downloaded when they change from only
    seed to some other priority
  * Fix crash when cleaning up mse::StreamSocket (bko#277076)
* Mon May  2 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Simplified License: to GPLv2+ which is the main license.
  * Fix locales removal if suse_version is not set.
  * %%kde_post_install is not needed.
* Mon May  2 2011 javier@opensuse.org
- Update to 1.1.1
  * Fix deadlock in utp::OutputQueue when packet sending fails
  * Fix bug causing scrape not to be done after first announce
  * Fix crash in DHT code caused by invalid addresses (269657)
  * Fix crash in DHT code caused by unsynchronized access to a QSet (270127)
  * Fix bug causing running time to be wrong when pausing torrents (271521)
* Wed Mar 16 2011 asterios.dramis@gmail.com
- Update to 1.1.0:
  * Improve performance of chunk selection code when there are many chunks
  * Fix crash in peer authentication cleanup (bko#266622)
  * Fix crash due to SIGBUS handler being overwritten by KDE's crash dialog
    system (bko#266842)
  * Be more lenient towards torrents with wrong announce-list field
    (bko#268145)
  * Fix root cause of SHA1HashGen crashes in 1.0 series (bko#268162)
- Spec file updates:
  * Removed Authors: from %%description (requirement for Factory submissions).
  * Minor update in %%files section.
* Sat Feb 26 2011 coolo@novell.com
- recommend -lang package again
* Fri Feb 25 2011 asterios.dramis@gmail.com
- Update to libktorrent-1.0.99rc1 (1.1rc1):
  * Fix bug in UPnP so that it works properly with D-Link DIR 635 routers
  * Fix crash due to manipulating timers in the wrong thread (261903)
  * Fix compiler warning in TimeEstimator (262618)
  * Fix crash due to cleaning up timer in the wrong thread (260712)
  * Fix crash due to not properly cleaning up Peers and everything related when
    switching to superseeding mode (261529)
  * Fix invalid read in utp timer cleanup code (263800)
  * Fix crashes at exit (264378, 256639)
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Summary:, Url: and %%description.
  * Changed License: to GPLv2+ and LGPLv2+ and MIT and BSD.
  * Updates in Buildrequires:, %%build, %%install and %%files sections.
  * Use Suggests: and not Recommends: for lang package.
  * Removed %%pre /sbin/ldconfig section (not needed).
- Removed libktorrent-1.1beta1-sprseedcrash.patch (fixed upstream).
- Removed libktorrent-po.tar.bz2 (not needed, its included in the package).
* Sat Jan 15 2011 davejplater@gmail.com
- Added patch libktorrent-1.1beta1-sprseedcrash.patch to fix crash
  when switching from seeding to superseeding or vice versa, while
  the torrent is running mostly with a private torrent. See :
  kde #(261529), first reported in kde #(262560).
* Mon Jan  3 2011 davejplater@gmail.com
- Update to libktorrent-1.0.80 (1.1beta1) fix kde #(261679) crash
  with rss syndication plugin.
- Upstream changes :
  * Video streaming support
  * Superseeding support
  * Data file moves are now tracked in the GUI
  * The GUI has been redesigned and now makes proper use of KDE's
    KParts technologie
  * The search plugin now uses webkit
  * Exclusion patterns have been added to the syndication plugin
    filters
  * And many other smaller changes. For a full overview of all the
    changes, take a look in the ChangeLog's of libktorrent and
    ktorrent
* Fri Dec 17 2010 davejplater@gmail.com
- Update to git20101211 fixes crash see (kde#260338)
- Upstream changes :
  * Backport several utp bugfixes from trunk.
  * Fix crash due to not checking for 0 pointer in multimedia file
  check.
  * Backport file selection bug from master CCBUG: 258138
* Tue Nov 30 2010 davejplater@gmail.com
- Update to git20101130 to fix (kde#258078)
- Upstream changes :
  * Add LIBKTORRENT_VERSION macro
  * Update MINOR version of master branch to 1
  * Improve MultiDataChecker file handling
  * Privatize PeerManager
  * Use weak pointers in PeerConnector and Authenticate,
  should fix a crash
  * Fix ChangeLog
* Mon Nov 22 2010 tittiatcoke@gmail.com
- Update to the latest git snapshot to build KGet with torrent
  support in KDE 4.6 Beta 1
* Mon Oct 18 2010 tittiatcoke@gmail.com
- update to 1.0.4: Fixing a deadlock and a crash in the µTP
    protocol code
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Mon Aug 30 2010 tittiatcoke@gmail.com
- update to 1.0.3: Fixing several bugs and rare crashes
* Fri Jul  9 2010 beineri@opensuse.org
- update to 1.0.2: bugfixes, renames libktorrent1 to libktorrent2
* Tue Jun 15 2010 tittiatcoke@gmail.com
- update to 1.0.1
  * Bugfixes
* Mon Jun  7 2010 dmueller@suse.de
- fix -lang package generation
* Wed May 26 2010 tittiatcoke@gmail.com
- Initial package 1.0.0
